.. _api:

API Reference
=============

The API reference is split up into four modules.
The main ``IniAbu`` class,
with which the user will most likely interact,
is described in :doc:`main`.

Querying classes for elements and isotopes
are respectively described in
:doc:`elements` and :doc:`isotopes`.

Finally, utility functions and classes
are described in :doc:`utilities`.

**Contents**:

.. toctree::
    :maxdepth: 2

    main
    elements
    isotopes
    utilities
